@@ -15,6 +15,7 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.Map.Entry;
 
+import jp.sourceforge.mergedoc.org.apache.commons.lang.StringUtils;
 import jp.sourceforge.mergedoc.pleiades.generator.Generator;
 import jp.sourceforge.mergedoc.pleiades.generator.Validator;
 import jp.sourceforge.mergedoc.pleiades.resource.Files;
@@ -23,8 +24,6 @@ import jp.sourceforge.mergedoc.pleiades.resource.Mnemonics;
 import jp.sourceforge.mergedoc.pleiades.resource.Property;
 import jp.sourceforge.mergedoc.pleiades.resource.PropertySet;
 
-import org.apache.commons.lang.StringUtils;
-
 /**
  * 言語パックから、ヘルプに関する日本語訳を抽出し、Pleiades 形式の
  * プロパティー・ファイルに出力するクラスです。
@@ -221,11 +220,8 @@ public class HelpExtractor extends AbstractExtractor {
 			return false;
 		}
 
-		if (uiValidator.validate(p).isSuccess()) {
-			return true;
-		}
+		return uiValidator.validate(p).isSuccess();
 
-		return false;
 	}
 
 	/**
@@ -257,8 +253,8 @@ public class HelpExtractor extends AbstractExtractor {
 
 					for (Property vTrans : vHelpTransProp) {
 
-						String enPart = vTrans.key;
-						String jaPart = vTrans.value;
+						String enPart = "(?s)" + vTrans.key;
+						String jaPart = "(?s)" + vTrans.value;
 
 						if (en.getText().matches(enPart)) {
 
