@@ -26,7 +26,7 @@ public class J10nHelpExtractor extends HelpExtractor {
 	 * @throws IOException 入出力例外が発生した場合
 	 */
 	public static void main(String... args) throws IOException {
-		inNlsFolder = Files.getFile("props/temp/help.test.nls");
+		inNlsFolder = Files.conf("props/temp/help.test.nls");
 		new J10nHelpExtractor().run("help", args);
 	}
 	
