@@ -6,40 +6,19 @@
  */
 package jp.sourceforge.mergedoc.pleiades.resource;
 
-import java.io.BufferedInputStream;
-import java.io.BufferedOutputStream;
-import java.io.BufferedWriter;
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.InputStreamReader;
-import java.io.OutputStream;
-import java.io.OutputStreamWriter;
-import java.io.Reader;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.ConcurrentModificationException;
-import java.util.Date;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Map;
+import jp.sourceforge.mergedoc.org.apache.commons.io.IOUtils;
+import jp.sourceforge.mergedoc.org.apache.commons.lang.CharEncoding;
+import jp.sourceforge.mergedoc.org.apache.commons.lang.StringUtils;
+import jp.sourceforge.mergedoc.pleiades.log.Logger;
+
+import java.io.*;
+import java.util.*;
 import java.util.Map.Entry;
-import java.util.Properties;
 import java.util.zip.Deflater;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
 import java.util.zip.ZipOutputStream;
 
-import org.apache.commons.io.IOUtils;
-import org.apache.commons.lang.StringUtils;
-
-import jp.sourceforge.mergedoc.pleiades.log.Logger;
-
 /**
  * プロパティー・セット・クラスです。
  * このクラスは java.util.Properties と比較し、以下の利点があります。
@@ -131,7 +110,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 	public PropertySet load(String... paths) {
 
 		for (String path : paths) {
-			File file = Files.getFile(path);
+			File file = Files.conf(path);
 			load(file);
 		}
 		return this;
@@ -245,7 +224,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 	 */
 	public List<String> store(String path, String comment) {
 
-		File resourceFile = Files.getFile(path);
+		File resourceFile = Files.conf(path);
 		return store(resourceFile, comment);
 	}
 
@@ -273,17 +252,15 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 		}
 
 		// ヘッダーの作成
-		List<String> headerList = new LinkedList<String>();
+		List<String> headerList = new ArrayList<String>();
 		headerList.add(saveConvertComment("このファイルは Pleiades により生成されました。" + size() + " エントリー。"));
-		headerList
-				.add("####################################################################################################");
+		headerList.add("####################################################################################################");
 		headerList.add("# ");
 		for (String s : comment.split("\\n")) {
 			headerList.add("# " + saveConvertComment(s));
 		}
 		headerList.add("# ");
-		headerList
-				.add("####################################################################################################");
+		headerList.add("####################################################################################################");
 		String header = StringUtils.join(headerList, "\n");
 
 		OutputStream os = null;
@@ -352,6 +329,9 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 	// -------------------------------------------------------------------------
 	// 以下、java.util.Properties の拡張
 
+	/** ロードカウント (非同期ロードは未対応) */
+	private int loadCount;
+
 	protected InputStream getInputStream(File file) throws IOException {
 
 		// 拡張子 .properties
@@ -373,7 +353,8 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 
 		loadFileWithoutLog(file);
 
-		log.info("load  %4.3f 秒 - %6d エントリー %s", (System.nanoTime() - startTime) / 1e+9, size(), file.getName());
+		log.info("load  %4.3f 秒 - %6d エントリー %s", (System.nanoTime() - startTime) / 1e+9, loadCount, file.getName());
+		loadCount = 0;
 	}
 
 	private void loadFileWithoutLog(File file) {
@@ -395,7 +376,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 	}
 
 	private void loadUTF8(InputStream is) throws IOException {
-        load0(new LineReader(new InputStreamReader(is, "UTF-8")));
+        load0(new LineReader(new InputStreamReader(is, CharEncoding.UTF_8)));
 	}
 
 	private void load0(LineReader lr) throws IOException {
@@ -448,13 +429,14 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 			String key = loadConvert(lr.lineBuf, 0, keyLen, convtBuf);
 			String value = loadConvert(lr.lineBuf, valueStart, limit - valueStart, convtBuf);
 			put(key, value);
+			loadCount++;
 		}
 	}
 
 	@SuppressWarnings("unchecked")
 	private List<String> store(OutputStream out, String comments) throws IOException {
 
-		BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(out, "UTF-8"));
+		BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(out, CharEncoding.UTF_8));
 		if (comments != null) {
 			writeln(writer, "#" + comments);
 		}
@@ -476,7 +458,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 
 		// キーでソート
 		List<String> keyList = new ArrayList<String>(c.keySet());
-		Collections.<String> sort(keyList, String.CASE_INSENSITIVE_ORDER);
+		Collections.sort(keyList, String.CASE_INSENSITIVE_ORDER);
 
 		for (String key : keyList) {
 			String val = get(key);
@@ -689,7 +671,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 		if (bufLen < 0) {
 			bufLen = Integer.MAX_VALUE;
 		}
-		StringBuffer outBuffer = new StringBuffer(bufLen);
+		StringBuilder outBuffer = new StringBuilder(bufLen);
 
 		for (int x = 0; x < len; x++) {
 			char aChar = theString.charAt(x);
