@@ -20,6 +20,20 @@ public class TranslationRuleTest extends TestCase {
 	/** 翻訳ルール */
 	private TranslationRule rule = new TranslationRule();
 
+	/** 翻訳ルール適用 */
+	private PropertySet apply(PropertySet inProp) {
+
+		for (Property p : inProp) {
+			System.out.println(p);
+		}
+		PropertySet outProp = rule.apply(inProp);
+		for (Property p : outProp) {
+			System.out.println(p);
+		}
+		System.out.println();
+		return outProp;
+	}
+
 	/** テスト */
 	public void testApply() {
 
@@ -55,10 +69,58 @@ public class TranslationRuleTest extends TestCase {
 			"CHKJ2412I: The return type must be serializable at runtime.  (EJB 1.1: 6.10) (RMI 1.3: 2.6).",
 			"CHKJ2412I: 戻りの型は実行時にシリアライズ可能でなければなりません。 (EJB 1.1: 6.10) (RMI 1.3: 2.6)。");
 		outProp = apply(inProp);
+		assertEquals(1, outProp.size());
 		assertEquals(
 			"戻りの型は実行時にシリアライズ可能でなければなりません。",
 			outProp.get("The return type must be serializable at runtime."));
 
+		// 句点分割 かっこ
+		inProp = new PropertySet();
+		inProp.put(
+			"CHKJ2408E: {0} must be public. (EJB 1.1: 9.2.4, 9.2.5)",
+			"CHKJ2408E: {0} は public でなければなりません。 (EJB 1.1: 9.2.4、9.2.5)");
+		outProp = apply(inProp);
+		assertEquals(2, outProp.size());
+		assertEquals("{0} は public でなければなりません。", outProp.get("{0} must be public."));
+		assertEquals("EJB 1.1: 9.2.4、9.2.5", outProp.get("EJB 1.1: 9.2.4, 9.2.5"));
+
+		// 句点分割 かっこ + .
+		inProp = new PropertySet();
+		inProp.put(
+			"CHKJ2408E: {0} must be public. (EJB 1.1: 9.2.4, 9.2.5).",
+			"CHKJ2408E: {0} は public でなければなりません。 (EJB 1.1: 9.2.4、9.2.5)。");
+		outProp = apply(inProp);
+		assertEquals(2, outProp.size());
+		assertEquals("{0} は public でなければなりません。", outProp.get("{0} must be public."));
+		assertEquals("EJB 1.1: 9.2.4、9.2.5", outProp.get("EJB 1.1: 9.2.4, 9.2.5"));
+
+		// 句点分割 かっこ + :
+		inProp = new PropertySet();
+		inProp.put(
+			"Full user name (first and last):",
+			"完全ユーザー名 (姓名):");
+		outProp = apply(inProp);
+		assertEquals(2, outProp.size());
+		assertEquals("完全ユーザー名", outProp.get("Full user name"));
+		assertEquals("(姓名):", outProp.get("(first and last):"));
+
+		// 句点分割 (K&R は翻訳されないため null)
+		inProp = new PropertySet();
+		inProp.put(
+			"K&R [built-in]",
+			"K&R [ビルトイン]");
+		outProp = apply(inProp);
+		assertEquals(null, outProp.get("K&R"));
+		assertEquals("ビルトイン", outProp.get("built-in"));
+
+		// 句点分割 対訳チェックで不正
+		inProp = new PropertySet();
+		inProp.put(
+			"Returns the percentage rank of a value.Return value is in the range [0..1]",
+			"値の割合 (%) の順序を返します。戻り値は範囲 [0..1] です");
+		outProp = apply(inProp);
+		assertEquals(1, outProp.size());
+
 		// トリム Eclipse エラーコード
 		inProp = new PropertySet();
 		inProp.put(
@@ -69,23 +131,6 @@ public class TranslationRuleTest extends TestCase {
 			"IWAJ0131I はコマンドのフィーチャーが null であるため、キーにフィーチャーを追加できません:",
 			outProp.get("IWAJ0131I Cannot add the feature to the key because the feature is null for the command:"));
 
-		// 句点分割 -
-		inProp = new PropertySet();
-		inProp.put(
-			"K&R [built-in]",
-			"K&R [ビルトイン]");
-		outProp = apply(inProp);
-		assertEquals("K&R", outProp.get("KR"));
-		assertEquals("ビルトイン", outProp.get("built-in"));
-
-		// 句点分割 対訳チェックで不正
-		inProp = new PropertySet();
-		inProp.put(
-			"Returns the percentage rank of a value.Return value is in the range [0..1]",
-			"値の割合 (%) の順序を返します。戻り値は範囲 [0..1] です");
-		outProp = apply(inProp);
-		assertEquals(1, outProp.size());
-
 		// 置換
 		inProp = new PropertySet();
 		inProp.put(
@@ -130,18 +175,4 @@ public class TranslationRuleTest extends TestCase {
 		assertEquals("詳細は使用不可", outProp.get("details unavailable"));
 		assertEquals("VM によってサポートされていません", outProp.get("not supported by VM"));
 	}
-
-	/** 翻訳ルール適用 */
-	private PropertySet apply(PropertySet inProp) {
-
-		for (Property p : inProp) {
-			System.out.println(p);
-		}
-		PropertySet outProp = rule.apply(inProp);
-		for (Property p : outProp) {
-			System.out.println(p);
-		}
-		System.out.println();
-		return outProp;
-	}
 }
