@@ -11,7 +11,7 @@ public class MnemonicsTest extends TestCase {
 
 	/** ニーモニックを英語から日本語に変換 */
 	private String convertMnemonicEnToJa(String enWithMnemonic, String en, String ja) {
-		String s = Mnemonics.convertMnemonicEnToJa(enWithMnemonic, en, ja);
+		String s = Mnemonics.convertEnToJa(enWithMnemonic, en, ja);
 		System.out.println(enWithMnemonic + "\n" + s + "\n");
 		return s;
 	}
@@ -26,13 +26,17 @@ public class MnemonicsTest extends TestCase {
 		
 		s = convertMnemonicEnToJa("'@&Override'", "'@Override'", "'@Override'");
 		assertEquals("'@Override'(&O)", s);
+
+		// ニーモニックとアクセラレーターではない @
+		s = convertMnemonicEnToJa("set&Up/@Before", "setUp/@Before", "setUp/@Before");
+		assertEquals("setUp/@Before(&U)", s);
 	}
 
 	/** テスト */
 	public void testRemoveEnMnemonic() {
 		
 		String enValue = "Ignore '&&' in &Java properties files";
-		String enNoMnemonic = Mnemonics.removeEnMnemonic(enValue);
+		String enNoMnemonic = Mnemonics.removeEn(enValue);
 		assertEquals("Ignore '&&' in Java properties files", enNoMnemonic);
 	}
 }
